

//	Preparations

#delimit ;

clear;
set more off;


//	Merge survey waves

use rscfp1989.dta;
generate Year=1989;
rename X1 Y1;
rename XX1 YY1;
save rscfp1989_year.dta, replace;
clear;

use rscfp1992.dta;
generate Year=1992;
save rscfp1992_year.dta, replace;
clear;

use rscfp1995.dta;
generate Year=1995;
save rscfp1995_year.dta, replace;
clear;

use rscfp1998.dta;
generate Year=1998;
save rscfp1998_year.dta, replace;
clear;

use rscfp2001.dta;
generate Year=2001;
save rscfp2001_year.dta, replace;
clear;

use rscfp2004.dta;
generate Year=2004;
save rscfp2004_year.dta, replace;
clear;

use rscfp2007.dta;
generate Year=2007;
save rscfp2007_year.dta, replace;
clear;

use rscfp2010.dta;
generate Year=2010;
save rscfp2010_year.dta, replace;
clear;

use rscfp1989_year.dta;
append using rscfp1992_year.dta rscfp1995_year.dta rscfp1998_year.dta rscfp2001_year.dta rscfp2004_year.dta rscfp2007_year.dta rscfp2010_year.dta;

keep Y1 YY1 Year edcl race OCCAT1 OCCAT2 married dbplant debt age hhsex kids lf 
wageinc bussefarminc intdivinc kginc ssretinc transfothinc cds stocks savbnd 
cashli  checking saving mmda mmmf mma call liq stmutf tfbmutf gbmutf obmutf 
comutf omutf nmmf notxbnd mortbnd govtbnd obnd bond irakh thrift futpen currpen 
retqliq annuit trusts  othma othfin fin nfin asset;


//	Merge macro data

merge m:1 Year using MacroData2.dta, nogenerate;

gen imp=Y1-YY1*10;
sort imp;


//	Variable generation and labelling

drop if Year==2010; // eliminate responses from 2010 for baseline estimates

*Create binary variables from categorial variables;
gen educ_none = (edcl==1);
gen educ_schooldipl = (edcl==2);
gen educ_somecollege = (edcl==3);
gen educ_collegedipl = (edcl==4);
gen race_white = (race==1);
gen race_black = (race==2);
gen race_hispanic = (race==3);
gen race_other = (race==5);
gen selfemployed = (OCCAT1==2);
gen occat2_manag = (OCCAT2==1);
gen occat2_tech = (OCCAT2==2);
gen occat2_other = (OCCAT2==3);
gen occat2_notworking = (OCCAT2==4);


*Label variables;
label variable married "Marital status of household head =1 if married or living with partner, =2 otherwise";
label variable race_white "=1 if white and non-hispanic";
label variable race_black "=1 if black";
label variable race_hispanic "=1 if hispanic";
label variable race_other "=1 if other";
label variable educ_none "=1 if HH head has not finished school";
label variable educ_schooldipl "=1 if HH head has school diploma";
label variable educ_somecollege "=1 if HH head has some college education without a degree";
label variable educ_collegedipl "=1 if HH head has a college diploma";
label variable occat2_manag "=1 if managerial/professional";
label variable occat2_tech "=1 if technical/sales/services";
label variable occat2_other "=1 if other incl. production/craft/repair/operators/farmers/foresters/fishers etc";
label variable occat2_notworking "=1 if not working";
label variable dbplant "Head or spouse/partner has a defined pension plan on current job or some type of pension from past job to be received in future";
label variable debt "Debt secured with house + debt for residential property other than prinicipal residence + other lines of credit + credit card debt + installment loans (vehicle, euduc, other)+ other debts (loans against pensions, life insurances)";
label variable age "Age of the household head";
label variable hhsex "Gender of the household head, male when available";
label variable kids "Number of children";
label variable lf "Labour force participation, =1 if working in some way, =0 otherwise";
label variable selfemployed "=1 if selfemployed";
label variable wageinc "Wage income of family in previous year before taxes";
label variable bussefarminc "Income of family from sole proprietorship or farm in previous year before taxes + family income in previous year from other businesses/investments/net rent/trusts/royalties";
label variable intdivinc "Income of family in previous year from non-taxable investments such as municipal bonds before tax + other interest before tax +  dividends before tax";
label variable kginc "Family income from net gains or losses from mutual funds, sale of stock/bonds/real estate in previous year before tax";
label variable ssretinc "Family income from retirement income/social security/pensions/annuities/other retirement programmes in previous year before tax";
label variable transfothinc "Family income from unemployment or worker's compensation + child support/alimony + TANF/food stamps/other welfare + other, before tax in previous year";

label variable cds "Certificates of deposit";
label variable stocks "Total market value of stocks held";
label variable savbnd "Savings bonds";
label variable cashli "Cash value of life insurance if liquidated immediately";

label variable checking "Average funds held in checking accounts other than money market accounts over last month";
label variable saving "Funds currently held in savings account";
label variable mmda "Funds held in money market deposit accounts including money market accounts used for checking";
label variable mmmf "Money market mutual funds and money market accounts not held at commercial banks, credit unions, etc. (not in mmda)";
label variable mma "=mmda+mmmf, i.e. money market accounts";
label variable call "Call accounts at brokerages";
label variable liq "=checking+saving+mma+call, i.e. liquidity";

label variable stmutf "Stock mutual funds";
label variable tfbmutf "Tax-free bond mutual funds";
label variable gbmutf "Government bond mutual funds";
label variable obmutf "Other bond mutual funds (corporate bonds, commercial paper, junk bonds, and all remaining)";
label variable comutf "Combination and other mutual funds (including stock and bonds, also reits and misc.)";
label variable omutf "Other mutual funds";
label variable nmmf "=stmutf+tfbmutf+gbmutf+obmutf+comutf+omutf, i.e. total directly-held mf's excluding mmmf's";

label variable notxbnd "Tax-exempt bonds (state and local bonds)";
label variable mortbnd "Mortgage-backed bonds";
label variable govtbnd "US gov. and gov. agency bonds and bills";
label variable obnd "Corporate and foreign bonds";
label variable bond "=notxbnd+mortbnd+govtbnd+obnd, i.e. total bonds (excluding bond funds, savings bonds)";

label variable irakh "Individual retirement accounts (IRAs), Keoghs";
label variable thrift "Thrift amounts";
label variable futpen "Future pensions";
label variable currpen "Current pensions";
label variable retqliq "=irakh+thrift+futpen+currpen, i.e. 'account-type' pensions";

label variable annuit "Cash value of annuities";
label variable trusts "Cash value of trusts or managed investment accounts";
label variable othma "=annuit+trusts, i.e. other managed assets";

label variable othfin "Other financial assets (loans to s.o. else, future proceeds, royalties, futures, non-public stock, deferred compensation, etc)";

label variable fin "=liq+cds+nmmf+stocks+bond+retqliq+savbnd+cashli+othma+othfin, ie total financial assets";
label variable nfin "total non-financial assets";
label variable asset "=fin+nfin, i.e. total assets";


*Generate financial asset categories;
gen s=stocks+stmutf+0.5*comutf+0.458*irakh+0.458*thrift+trusts;
gen q=savbnd+notxbnd+0.779*govtbnd+tfbmutf+0.779*gbmutf+0.389*comutf+0.184*irakh+0.184*thrift;				
gen b=0.221*govtbnd+obnd+mortbnd+liq+cds+0.221*gbmutf+obmutf+0.111*comutf+omutf+0.358*irakh+0.358*thrift+currpen+cashli+annuit;

gen finass=s+b+q;
gen sofinass=s/finass;
gen bofinass=b/finass;
gen qofinass=q/finass;


*Age groups;
gen Agegroup=0;
replace Agegroup=2628 if age>=26 & age<=28;
replace Agegroup=2931 if age>=29 & age<=31;
replace Agegroup=3234 if age>=32 & age<=34;
replace Agegroup=3537 if age>=35 & age<=37;
replace Agegroup=3840 if age>=38 & age<=40;
replace Agegroup=4143 if age>=41 & age<=43;
replace Agegroup=4446 if age>=44 & age<=46;
replace Agegroup=4749 if age>=47 & age<=49;
replace Agegroup=5052 if age>=50 & age<=52;
replace Agegroup=5355 if age>=53 & age<=55;
replace Agegroup=5658 if age>=56 & age<=58;
replace Agegroup=5961 if age>=59 & age<=61;
replace Agegroup=6264 if age>=62 & age<=64;
replace Agegroup=6567 if age>=65 & age<=67;
replace Agegroup=6870 if age>=68 & age<=70;
replace Agegroup=7173 if age>=71 & age<=73;
replace Agegroup=7476 if age>=74 & age<=76;

drop if Agegroup==0; // eliminate respondents that do not fall into the age groups considered


* Age, period and cohort dummies;
gen AgeD2628 = (Agegroup==2628);
gen AgeD2931 = (Agegroup==2931);
gen AgeD3234 = (Agegroup==3234);
gen AgeD3537 = (Agegroup==3537);
gen AgeD3840 = (Agegroup==3840);
gen AgeD4143 = (Agegroup==4143);
gen AgeD4446 = (Agegroup==4446);
gen AgeD4749 = (Agegroup==4749);
gen AgeD5052 = (Agegroup==5052);
gen AgeD5355 = (Agegroup==5355);
gen AgeD5658 = (Agegroup==5658);
gen AgeD5961 = (Agegroup==5961);
gen AgeD6264 = (Agegroup==6264);
gen AgeD6567 = (Agegroup==6567);
gen AgeD6870 = (Agegroup==6870);
gen AgeD7173 = (Agegroup==7173);
gen AgeD7476 = (Agegroup==7476);

gen Time1989 = (Year==1989);
gen Time1992 = (Year==1992);
gen Time1995 = (Year==1995);
gen Time1998 = (Year==1998);
gen Time2001 = (Year==2001);
gen Time2004 = (Year==2004);
gen Time2007 = (Year==2007);

gen Cohort6163 = 0;
replace Cohort6163 = 1 if Year==1989 & Agegroup==2628;
replace Cohort6163 = 1 if Year==1992 & Agegroup==2931;
replace Cohort6163 = 1 if Year==1995 & Agegroup==3234;
replace Cohort6163 = 1 if Year==1998 & Agegroup==3537;
replace Cohort6163 = 1 if Year==2001 & Agegroup==3840;
replace Cohort6163 = 1 if Year==2004 & Agegroup==4143;
replace Cohort6163 = 1 if Year==2007 & Agegroup==4446;

gen Cohort5860 = 0;
replace Cohort5860 = 1 if Year==1989 & Agegroup==2931;
replace Cohort5860 = 1 if Year==1992 & Agegroup==3234;
replace Cohort5860 = 1 if Year==1995 & Agegroup==3537;
replace Cohort5860 = 1 if Year==1998 & Agegroup==3840;
replace Cohort5860 = 1 if Year==2001 & Agegroup==4143;
replace Cohort5860 = 1 if Year==2004 & Agegroup==4446;
replace Cohort5860 = 1 if Year==2007 & Agegroup==4749;

gen Cohort5557 = 0;
replace Cohort5557 = 1 if Year==1989 & Agegroup==3234;
replace Cohort5557 = 1 if Year==1992 & Agegroup==3537;
replace Cohort5557 = 1 if Year==1995 & Agegroup==3840;
replace Cohort5557 = 1 if Year==1998 & Agegroup==4143;
replace Cohort5557 = 1 if Year==2001 & Agegroup==4446;
replace Cohort5557 = 1 if Year==2004 & Agegroup==4749;
replace Cohort5557 = 1 if Year==2007 & Agegroup==5052;

gen Cohort5254 = 0;
replace Cohort5254 = 1 if Year==1989 & Agegroup==3537;
replace Cohort5254 = 1 if Year==1992 & Agegroup==3840;
replace Cohort5254 = 1 if Year==1995 & Agegroup==4143;
replace Cohort5254 = 1 if Year==1998 & Agegroup==4446;
replace Cohort5254 = 1 if Year==2001 & Agegroup==4749;
replace Cohort5254 = 1 if Year==2004 & Agegroup==5052;
replace Cohort5254 = 1 if Year==2007 & Agegroup==5355;

gen Cohort4951 = 0;
replace Cohort4951 = 1 if Year==1989 & Agegroup==3840;
replace Cohort4951 = 1 if Year==1992 & Agegroup==4143;
replace Cohort4951 = 1 if Year==1995 & Agegroup==4446;
replace Cohort4951 = 1 if Year==1998 & Agegroup==4749;
replace Cohort4951 = 1 if Year==2001 & Agegroup==5052;
replace Cohort4951 = 1 if Year==2004 & Agegroup==5355;
replace Cohort4951 = 1 if Year==2007 & Agegroup==5658;

gen Cohort4648 = 0;
replace Cohort4648 = 1 if Year==1989 & Agegroup==4143;
replace Cohort4648 = 1 if Year==1992 & Agegroup==4446;
replace Cohort4648 = 1 if Year==1995 & Agegroup==4749;
replace Cohort4648 = 1 if Year==1998 & Agegroup==5052;
replace Cohort4648 = 1 if Year==2001 & Agegroup==5355;
replace Cohort4648 = 1 if Year==2004 & Agegroup==5658;
replace Cohort4648 = 1 if Year==2007 & Agegroup==5961;

gen Cohort4345 = 0;
replace Cohort4345 = 1 if Year==1989 & Agegroup==4446;
replace Cohort4345 = 1 if Year==1992 & Agegroup==4749;
replace Cohort4345 = 1 if Year==1995 & Agegroup==5052;
replace Cohort4345 = 1 if Year==1998 & Agegroup==5355;
replace Cohort4345 = 1 if Year==2001 & Agegroup==5658;
replace Cohort4345 = 1 if Year==2004 & Agegroup==5961;
replace Cohort4345 = 1 if Year==2007 & Agegroup==6264;

gen Cohort4042 = 0;
replace Cohort4042 = 1 if Year==1989 & Agegroup==4749;
replace Cohort4042 = 1 if Year==1992 & Agegroup==5052;
replace Cohort4042 = 1 if Year==1995 & Agegroup==5355;
replace Cohort4042 = 1 if Year==1998 & Agegroup==5658;
replace Cohort4042 = 1 if Year==2001 & Agegroup==5961;
replace Cohort4042 = 1 if Year==2004 & Agegroup==6264;
replace Cohort4042 = 1 if Year==2007 & Agegroup==6567;

gen Cohort3739 = 0;
replace Cohort3739 = 1 if Year==1989 & Agegroup==5052;
replace Cohort3739 = 1 if Year==1992 & Agegroup==5355;
replace Cohort3739 = 1 if Year==1995 & Agegroup==5658;
replace Cohort3739 = 1 if Year==1998 & Agegroup==5961;
replace Cohort3739 = 1 if Year==2001 & Agegroup==6264;
replace Cohort3739 = 1 if Year==2004 & Agegroup==6567;
replace Cohort3739 = 1 if Year==2007 & Agegroup==6870;

gen Cohort3436 = 0;
replace Cohort3436 = 1 if Year==1989 & Agegroup==5355;
replace Cohort3436 = 1 if Year==1992 & Agegroup==5658;
replace Cohort3436 = 1 if Year==1995 & Agegroup==5961;
replace Cohort3436 = 1 if Year==1998 & Agegroup==6264;
replace Cohort3436 = 1 if Year==2001 & Agegroup==6567;
replace Cohort3436 = 1 if Year==2004 & Agegroup==6870;
replace Cohort3436 = 1 if Year==2007 & Agegroup==7173;

gen Cohort3133 = 0;
replace Cohort3133 = 1 if Year==1989 & Agegroup==5658;
replace Cohort3133 = 1 if Year==1992 & Agegroup==5961;
replace Cohort3133 = 1 if Year==1995 & Agegroup==6264;
replace Cohort3133 = 1 if Year==1998 & Agegroup==6567;
replace Cohort3133 = 1 if Year==2001 & Agegroup==6870;
replace Cohort3133 = 1 if Year==2004 & Agegroup==7173;
replace Cohort3133 = 1 if Year==2007 & Agegroup==7476;

gen InCohorts=Cohort3133+Cohort3436+Cohort3739+Cohort4042+Cohort4345+Cohort4648+Cohort4951+Cohort5254+Cohort5557+Cohort5860+Cohort6163;


*Generate dummies for holders of asset categories;
gen Stockholder=0;
replace Stockholder=1 if s>=1;
replace Stockholder=. if sofinass==.;

gen Qholder=0;
replace Qholder=1 if q>=1;
replace Qholder=. if qofinass==.;


//	Save dataset, export portfolio share data

save rscfp1989_2010.dta, replace;

*export portfolio share data;
keep Year Agegroup sofinass bofinass qofinass;
outsheet using SCF_outsheetdata_portshares.dat, replace;

clear;
