
clear;
clc;

%% SCF Estimates

% Long-term debt

Q_DP_data=importdata('Q_DP.dat');
Q_DP_partprob=Q_DP_data.data(:,1);
Q_DP_condshare=Q_DP_data.data(:,2)+max(Q_DP_data.data(:,3));

Q_PCA_data=importdata('Q_PCA.dat');
Q_PCA_partprob=Q_PCA_data.data(:,1);
Q_PCA_condshare=Q_PCA_data.data(:,2)+max(Q_PCA_data.data(:,3));


% Stocks

S_DP_data=importdata('S_DP.dat');
S_DP_partprob=S_DP_data.data(:,1);
S_DP_condshare=S_DP_data.data(:,2)+max(S_DP_data.data(:,3));

S_PCA_data=importdata('S_PCA.dat');
S_PCA_partprob=S_PCA_data.data(:,1);
S_PCA_condshare=S_PCA_data.data(:,2)+max(S_PCA_data.data(:,3));


%% Model

load Model_2_Simulation.mat

part_mean=part_mean(3:47)';
q_share_condpart_mean=q_share_condpart_mean(3:47)';
s_share_condpart_mean=s_share_condpart_mean(3:47)';

part_mean_ag=zeros(length(part_mean)/3,1);
q_share_condpart_mean_ag=zeros(length(part_mean)/3,1);
s_share_condpart_mean_ag=zeros(length(part_mean)/3,1);

for ii=1:length(part_mean_ag)
   part_mean_ag(ii)=mean(part_mean((ii-1)*3+1:(ii-1)*3+3));
   q_share_condpart_mean_ag(ii)=mean(q_share_condpart_mean((ii-1)*3+1:(ii-1)*3+3)); 
   s_share_condpart_mean_ag(ii)=mean(s_share_condpart_mean((ii-1)*3+1:(ii-1)*3+3));
end


%% Figure


set(figure,'defaultAxesColorOrder',[0 0 0 ; 0 0 0]);

subplot(2,2,1)
hold on;
xticks([2 6 10 14])
xticklabels({'32-34','44-46','56-58','68-70'})
xlabel('Age group','FontSize',11,'Interpreter','latex')
title('a)','FontSize',11,'Interpreter','latex')
yyaxis left
plot(part_mean_ag,'-k','linewidth',1)
axis([0 16 0 1])
yticks([0 0.25 0.5 0.75 1])
ylabel({'Participation probability','(Long-term gov. debt)'},'FontSize',11,'Interpreter','latex')
yyaxis right
plot(Q_DP_partprob(1:15),'+-r')
plot(Q_PCA_partprob(1:15),'*-c')
axis([0 16 0.72 0.9])
yticks([ 0.75 0.8 0.85 0.9])
legend({'Model (left scale)','Deaton-Paxson (right scale)','Principal Components (right scale)'},'FontSize',11,'Interpreter','latex','Location','southoutside','Orientation','horizontal','Box','off')
hold off;
box on;

subplot(2,2,2)
hold on;
xticks([2 6 10 14])
xticklabels({'32-34','44-46','56-58','68-70'})
xlabel('Age group','FontSize',11,'Interpreter','latex')
title('b)','FontSize',11,'Interpreter','latex')
yyaxis left
plot(q_share_condpart_mean_ag,'-k','linewidth',1)
axis([1 16 0 0.55])
yticks([0 0.2 0.4])
ylabel({'Portfolio share','(Long-term gov. debt)'},'FontSize',11,'Interpreter','latex')
yyaxis right
plot(2:15,Q_DP_condshare(2:15),'+-r')
plot(2:15,Q_PCA_condshare(2:15),'*-c')
axis([1 16 0.135 0.22])
yticks([0.14 0.18 0.22])
hold off;
box on;

subplot(2,2,3)
hold on;
xticks([2 6 10 14])
xticklabels({'32-34','44-46','56-58','68-70'})
xlabel('Age group','FontSize',11,'Interpreter','latex')
title('c)','FontSize',11,'Interpreter','latex')
yyaxis left
plot(part_mean_ag,'-k','linewidth',1)
axis([0 16 0 1])
yticks([0 0.25 0.5 0.75 1])
ylabel({'Participation probability','(Stocks)'},'FontSize',11,'Interpreter','latex')
yyaxis right
plot(S_DP_partprob(1:15),'+-r')
plot(S_PCA_partprob(1:15),'*-c')
axis([0 16 0.72 0.9])
yticks([ 0.75 0.8 0.85 0.9])
hold off;
box on;

subplot(2,2,4)
hold on;
xticks([2 6 10 14])
xticklabels({'32-34','44-46','56-58','68-70'})
xlabel('Age group','FontSize',11,'Interpreter','latex')
title('d)','FontSize',11,'Interpreter','latex')
yyaxis left
plot(s_share_condpart_mean_ag,'-k','linewidth',1)
axis([1 16 0 1])
yticks([0 0.25 0.5 0.75 1])
ylabel({'Portfolio share','(Stocks)'},'FontSize',11,'Interpreter','latex')
yyaxis right
plot(2:15,S_DP_condshare(2:15),'+-r')
plot(2:15,S_PCA_condshare(2:15),'*-c')
axis([1 16 0.45 0.63])
yticks([0.45 0.5 0.55 0.6])
hold off;
box on;

